.. Copyright 2013, 2014 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.domainui.accounts
------------------------------

.. automodule:: reahl.domainui.accounts



AccountUI
"""""""""

.. autoclass:: AccountUI
   :members:

